==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/operationsmanagement/kotlin/inputs/SolutionPlanArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationsmanagement.kotlin.inputs

import com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Plan for solution object supported by the OperationsManagement resource provider.
 * @property name name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
 * @property product name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
 * @property promotionCode promotionCode, Not really used now, can you left as empty
 * @property publisher Publisher name. For gallery solution, it is Microsoft.
 */
public data class SolutionPlanArgs(
    public val name: Output<String>? = null,
    public val product: Output<String>? = null,
    public val promotionCode: Output<String>? = null,
    public val publisher: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs> {
    override fun toJava(): com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs =
        com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .product(product?.applyValue({ args0 -> args0 }))
            .promotionCode(promotionCode?.applyValue({ args0 -> args0 }))
            .publisher(publisher?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SolutionPlanArgs].
 */
@PulumiTagMarker
public class SolutionPlanArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var product: Output<String>? = null

    private var promotionCode: Output<String>? = null

    private var publisher: Output<String>? = null

    /**
     * @param value name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
     */
    @JvmName("rvuhmycuoxfiummc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
     */
    @JvmName("hgetswnibwnmuuiu")
    public suspend fun product(`value`: Output<String>) {
        this.product = value
    }

    /**
     * @param value promotionCode, Not really used now, can you left as empty
     */
    @JvmName("agkwsocnunsmphql")
    public suspend fun promotionCode(`value`: Output<String>) {
        this.promotionCode = value
    }

    /**
     * @param value Publisher name. For gallery solution, it is Microsoft.
     */
    @JvmName("elawqxnafjlvxlxs")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
     */
    @JvmName("nwwcrqbfdydmvxrx")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
     */
    @JvmName("gqihblnosbnyugqa")
    public suspend fun product(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.product = mapped
    }

    /**
     * @param value promotionCode, Not really used now, can you left as empty
     */
    @JvmName("ieiygfcluugerdso")
    public suspend fun promotionCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.promotionCode = mapped
    }

    /**
     * @param value Publisher name. For gallery solution, it is Microsoft.
     */
    @JvmName("ybjbyymrqfjysuwc")
    public suspend fun publisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    internal fun build(): SolutionPlanArgs = SolutionPlanArgs(
        name = name,
        product = product,
        promotionCode = promotionCode,
        publisher = publisher,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/operationsmanagement/kotlin/inputs/SolutionPlanArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationsmanagement.kotlin.inputs

import com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Plan for solution object supported by the OperationsManagement resource provider.
 * @property name name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
 * @property product name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
 * @property promotionCode promotionCode, Not really used now, can you left as empty
 * @property publisher Publisher name. For gallery solution, it is Microsoft.
 */
public data class SolutionPlanArgs(
    public val name: Output<String>? = null,
    public val product: Output<String>? = null,
    public val promotionCode: Output<String>? = null,
    public val publisher: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs> {
    override fun toJava(): com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs =
        com.pulumi.azurenative.operationsmanagement.inputs.SolutionPlanArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .product(product?.applyValue({ args0 -> args0 }))
            .promotionCode(promotionCode?.applyValue({ args0 -> args0 }))
            .publisher(publisher?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SolutionPlanArgs].
 */
@PulumiTagMarker
public class SolutionPlanArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var product: Output<String>? = null

    private var promotionCode: Output<String>? = null

    private var publisher: Output<String>? = null

    /**
     * @param value name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
     */
    @JvmName("ixifhkkxcokbvkbo")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
     */
    @JvmName("dccneyjhaqqjykrc")
    public suspend fun product(`value`: Output<String>) {
        this.product = value
    }

    /**
     * @param value promotionCode, Not really used now, can you left as empty
     */
    @JvmName("mnbaxtiymmdctfvf")
    public suspend fun promotionCode(`value`: Output<String>) {
        this.promotionCode = value
    }

    /**
     * @param value Publisher name. For gallery solution, it is Microsoft.
     */
    @JvmName("xxpipqlalnwckorh")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value name of the solution to be created. For Microsoft published solution it should be in the format of solutionType(workspaceName). SolutionType part is case sensitive. For third party solution, it can be anything.
     */
    @JvmName("okjksilliywpqvqq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value name of the solution to enabled/add. For Microsoft published gallery solution it should be in the format of OMSGallery/<solutionType>. This is case sensitive
     */
    @JvmName("wkhhdlvwmrfxswje")
    public suspend fun product(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.product = mapped
    }

    /**
     * @param value promotionCode, Not really used now, can you left as empty
     */
    @JvmName("swvxxffknpifwagi")
    public suspend fun promotionCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.promotionCode = mapped
    }

    /**
     * @param value Publisher name. For gallery solution, it is Microsoft.
     */
    @JvmName("ktukmfdnybuilcdl")
    public suspend fun publisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    internal fun build(): SolutionPlanArgs = SolutionPlanArgs(
        name = name,
        product = product,
        promotionCode = promotionCode,
        publisher = publisher,
    )
}
